@@ -2,13 +2,14 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '1.017000';
+$MetaCPAN::Client::VERSION = '1.018000';
 use Moo;
 use Carp;
 
 use MetaCPAN::Client::Request;
 use MetaCPAN::Client::Author;
 use MetaCPAN::Client::Distribution;
+use MetaCPAN::Client::DownloadURL;
 use MetaCPAN::Client::Module;
 use MetaCPAN::Client::File;
 use MetaCPAN::Client::Favorite;
@@ -30,6 +31,14 @@ my @supported_searches = qw<
 sub BUILDARGS {
     my ( $class, %args ) = @_;
 
+    # default 'domain' for 'version => v0|v1'
+    if ( exists $args{version} ) {
+        $args{domain} //=
+            $args{version} eq 'v0' ? 'api.metacpan.org' :
+            $args{version} eq 'v1' ? 'fastapi.metacpan.org' :
+            undef;
+    }
+
     $args{'request'} ||= MetaCPAN::Client::Request->new(
         ( ua      => $args{ua}      )x!! $args{ua},
         ( domain  => $args{domain}  )x!! $args{domain},
@@ -159,6 +168,16 @@ sub all {
     return $self->$type( { __MATCH_ALL__ => 1 }, $params );
 }
 
+sub download_url {
+    my $self   = shift;
+    my $module = shift;
+
+    $self->request->version eq 'v0'
+        and croak "download_url: not supported in v0 (use version => v1)";
+
+    return $self->_get( 'download_url', $module );
+}
+
 ###
 
 sub _get {
@@ -180,6 +199,8 @@ sub _get {
     ref $response eq 'HASH'
         or croak sprintf( 'Failed to fetch %s (%s)', ucfirst($type), $arg );
 
+    $type = 'DownloadURL' if $type eq 'download_url';
+
     my $class = 'MetaCPAN::Client::' . ucfirst($type);
     return $class->new_from_request($response, $self);
 }
@@ -335,7 +356,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 1.017000
+version 1.018000
 
 =head1 SYNOPSIS
 
@@ -351,6 +372,8 @@ version 1.017000
     use MetaCPAN::Client;
 
     my $mcpan = MetaCPAN::Client->new(
+      version => 'v1',
+
       ua => HTTP::Tiny::Mech->new(
         mechua => WWW::Mechanize::Cached->new(
           cache => CHI->new(
@@ -384,6 +407,16 @@ instead of the default, which is L<HTTP::Tiny>.
 Then it can be used to fetch the user agent object used by
 L<MetaCPAN::Client::Request>.
 
+=head2 version
+
+API version (supported: 'v0', 'v1')
+
+This will also set default value to your 'domain' (unless given)
+
+=head2 domain
+
+If given, will be used to alter the API domain.
+
 =head1 METHODS
 
 =head2 author
@@ -498,6 +531,14 @@ Retrieve all matches for authors/modules/distributions/favorites or releases.
 When called with a second parameter containing a hash ref,
 will support the following keys:
 
+=head2 download_url
+
+Retrieve information from the 'download_url' endpoint (v1 only)
+
+    my $download_url = $mcpan->download_url('Moose')
+
+Returns a L<MetaCPAN::Client::DownloadURL> object
+
 =head3 fields
 
 See SEARCH PARAMS.
